@@ -35,6 +35,7 @@ class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  columnsToCategorical=[],
                  keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -45,7 +46,6 @@ class H2OGAM(H2OGAMParams, H2OSupervisedAlgorithmWithFoldColumn, FamilyBasedH2OT
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  seed=-1,
                  family="AUTO",
                  tweedieVariancePower=0.0,
